@@ -7,23 +7,28 @@ from django.core.exceptions import MiddlewareNotUsed
 
 class PdbMiddleware(object):
     """
-    Middleware to break into pdb at the start of every view.
+    Middleware to break into pdb at the start of views.
+
+    If `always_break` is set, due to `runserver --pdb` this will break
+    into pdb at the start of every view.
+
+    Otherwise it will break into pdb at the start of the view if
+    a 'pdb' GET parameter is set on the request url.
     """
 
-    #enabled = False
-
-    #def __init__(self):
-    #    """
-    #    Remove this middleware on startup if '--pdb' is not being used.
-    #    """
-    #    if not self.enabled:
-    #        raise MiddlewareNotUsed
+    always_break = False
   
     def process_view(self, request, view_func, view_args, view_kwargs):
         """
         If running with '--pdb', set a breakpoint at the start
         of each of each view before it gets called.
         """
+        
+        # Skip out unless using `runserver --pdb`,
+        # or `pdb` is in the command line parameters
+        if not (self.always_break or 'pdb' in request.GET):
+            return
+ 
         filename = inspect.getsourcefile(view_func)
         basename = os.path.basename(filename)
         dirname = os.path.basename(os.path.dirname(filename))
@@ -33,7 +38,7 @@ class PdbMiddleware(object):
         funcname = view_func.__name__
 
         print
-        print '%s %s' % (request.method, request.path)
+        print '%s %s' % (request.method, request.get_full_path())
         print 'function "%s" in %s/%s:%d' % (funcname, dirname, basename, lineno)
         print 'args: %s' % (view_args,)
         print 'kwargs: %s' % (view_kwargs,)
